﻿Imports System.Data
Imports System.Data.SqlClient
Class Articles

    Private primeraCarga As Boolean = True
    Private Sub Articles_Loaded(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles Me.Loaded

        If primeraCarga Then
            MostrarArticles("")
            txtId.Focus()
            primeraCarga = False
        End If

    End Sub

#Region "Mostrar Dades"

    Private Sub MostrarArticles(ByVal filtro As String)

        Try
            Dim l As ServeiChiquiPark.Article()
            l = Configuracio.Instance.Servei.GetArticles(filtro)
            lvArticles.DataContext = l

        Catch ex As Exception
            MsgBox("No podem conectar amb el servidor de dades", MsgBoxStyle.Critical)
        End Try


    End Sub
    Private Sub MostrarArticle(ByVal id As Long)

        Try
            Dim a As ServeiChiquiPark.Article
            a = Configuracio.Instance.Servei.GetArticle(id)
            If a IsNot Nothing Then OmplirTextBox(a)

        Catch ex As Exception
            MsgBox("No podem conectar amb el servidor de dades", MsgBoxStyle.Critical)
        End Try

    End Sub
    Private Sub OmplirTextBox(ByVal art As ServeiChiquiPark.Article)

        txtId.Text = art.Id
        txtNom.Text = art.Nom
        txtPreu.Text = art.Preu
        chkActivitat.IsChecked = art.Tipus
        txtPath.Text = art.Imatge
        If txtPath.Text <> "" Then MostrarImatge()

    End Sub
    Private Sub ResetTextBox()

        txtId.Text = ""
        txtNom.Text = ""
        txtPreu.Text = ""
        chkActivitat.IsChecked = False
        txtPath.Text = ""
        img.Source = Nothing

        lvArticles.SelectedIndex = -1

        txtId.Focus()

    End Sub
    Private Sub MostrarImatge()

        Try
            Dim bmi As New BitmapImage()
            bmi.BeginInit()
            bmi.UriSource = New Uri(txtPath.Text)
            bmi.EndInit()
            img.Source = bmi

        Catch ex As Exception
            txtPath.Text = ""
            img.Source = Nothing
        End Try

    End Sub
    Private Sub lvArticles_SelectionChanged(ByVal sender As Object, ByVal e As System.Windows.Controls.SelectionChangedEventArgs) Handles lvArticles.SelectionChanged

        If lvArticles.SelectedItem IsNot Nothing Then OmplirTextBox(lvArticles.SelectedItem)

    End Sub

#End Region

#Region "Validació"

    Private Sub txtId_KeyDown(ByVal sender As Object, ByVal e As System.Windows.Input.KeyEventArgs) Handles txtId.KeyDown, txtNom.KeyDown, txtPreu.KeyDown, txtFiltro.KeyDown

        If e.Key = Key.Enter Then
            Select Case sender.Name
                Case txtFiltro.Name : MostrarArticles(txtFiltro.Text)
                Case txtPath.Name : If txtPath.Text <> "" Then MostrarImatge()
                Case Else
                    sender.MoveFocus(New TraversalRequest(FocusNavigationDirection.Next))
            End Select
        End If

    End Sub
    Private Sub txtId_LostFocus(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles txtId.LostFocus, txtPreu.LostFocus

        Select Case sender.Name
            Case txtId.Name
                Dim id As Long
                If Not Long.TryParse(txtId.Text, id) Then id = -1
                If id > 0 Then
                    MostrarArticle(id)
                Else
                    txtId.Text = ""
                End If
            Case txtPreu.Name
                Dim preu As Double
                If Not Double.TryParse(txtPreu.Text.Replace(".", ","), preu) Then preu = 0
                txtPreu.Text = Format(preu, "#.##")
        End Select

    End Sub

#End Region

#Region "Manteniment Dades"

    Private Sub btnGravar_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles btnGravar.Click

        Dim id As Long
        If Not Long.TryParse(txtId.Text, id) OrElse id <= 0 Then id = -1

        Cursor = Cursors.Wait

        Dim art As New ServeiChiquiPark.Article

        art.Id = id
        art.Nom = txtNom.Text
        If Not Double.TryParse(txtPreu.Text, art.Preu) Then art.Preu = 0.0
        art.Tipus = chkActivitat.IsChecked
        If img.Source IsNot Nothing Then
            art.Imatge = txtPath.Text
        Else : art.Imatge = ""
        End If

        Try
            If Configuracio.Instance.Servei.SetArticle(art) Then
                MostrarArticles(txtFiltro.Text)
                ResetTextBox()
            Else
                MsgBox("Error al guardar l'article !", MsgBoxStyle.Exclamation)
            End If

        Catch ex As Exception
            MsgBox("No podem conectar amb el servidor de dades", MsgBoxStyle.Critical)
        End Try

        Cursor = Cursors.Arrow

    End Sub
    Private Sub btnNou_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles btnNou.Click

        ResetTextBox()

    End Sub
    Private Sub btnTancar_Click(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles btnTancar.Click

        If Me.Parent IsNot Nothing Then CType(Me.Parent, DockPanel).Visibility = Windows.Visibility.Collapsed

    End Sub
    Private Sub btnEliminar_Click(sender As Object, e As System.Windows.RoutedEventArgs) Handles btnEliminar.Click

        If txtId.Text <> "" AndAlso MsgBox("Vol esborrar l'article ? ", MsgBoxStyle.YesNo) = MsgBoxResult.Yes Then
            Dim lng As Long
            If Not Long.TryParse(txtId.Text, lng) Then lng = 0
            If lng > 0 Then
                Try
                    Dim res As Byte = Configuracio.Instance.Servei.DeleteArticle(lng)
                    Select Case res
                        Case 0 : MsgBox("Error al eliminar l'article !", MsgBoxStyle.Exclamation)
                        Case 1
                            ResetTextBox()
                            MostrarArticles(txtFiltro.Text)
                        Case 2 : MsgBox("Error l'article està assignat a reserves/tickets/promocions !", MsgBoxStyle.Exclamation)
                    End Select
                Catch ex As Exception
                    MsgBox("No podem conectar amb el servidor de dades", MsgBoxStyle.Critical)
                End Try
            End If
        End If

    End Sub
    Private Sub btnPath_Click(sender As Object, e As System.Windows.RoutedEventArgs) Handles btnPath.Click

        Dim dlg As New Microsoft.Win32.OpenFileDialog()

        If dlg.ShowDialog() Then
            txtPath.Text = dlg.FileName
            MostrarImatge()
        End If

    End Sub

#End Region
    
End Class

'Classe de conversió de dades en el grid boolean --> Si / No
Class ObtenerSiNo
    Implements IValueConverter

    Public Function Convert(ByVal value As Object, ByVal targetType As Type, ByVal parameter As Object, ByVal culture As System.Globalization.CultureInfo) As Object Implements IValueConverter.Convert

        If TypeOf value Is Boolean AndAlso value Then
            Return "Si"
        Else : Return "No"
        End If

    End Function

    Public Function ConvertBack(ByVal value As Object, ByVal targetType As Type, ByVal parameter As Object, ByVal culture As System.Globalization.CultureInfo) As Object Implements IValueConverter.ConvertBack

        Throw New NotImplementedException()
    End Function

End Class
