﻿Partial Public Class MenuUsuari
    Inherits Page

    Private fechaModificada As Boolean = False
    Private IdSeleccionat As Integer = -1
    Public Sub New()
        InitializeComponent()
    End Sub

    'Se ejecuta cuando el usuario navega a esta página.
    Protected Overrides Sub OnNavigatedTo(ByVal e As System.Windows.Navigation.NavigationEventArgs)

        'si no hi ha una instancia d'usuari a la configuració redireccionem cap al login
        If Configuracio.Instance.Usuari Is Nothing Then
            NavigationService.Navigate(New Uri("/LoginUsuari.xaml", UriKind.RelativeOrAbsolute))
            Return
        End If

        txtUsuari.Text = Configuracio.Instance.Usuari.Login

        AddHandler Configuracio.Instance.Servei.GetClientReservesCompleted, AddressOf ClientReservesCompleted
        AddHandler Configuracio.Instance.Servei.GetTipusArticlesCompleted, AddressOf TipusArticlesCompleted
        AddHandler Configuracio.Instance.Servei.GetDiaReservesCompleted, AddressOf DiaReservesCompleted
        AddHandler Configuracio.Instance.Servei.SetReservaCompleted, AddressOf SetReservaCompleted
        AddHandler Configuracio.Instance.Servei.DeleteReservaCompleted, AddressOf DeleteReservaCompleted
        Configuracio.Instance.Servei.GetClientReservesAsync(Configuracio.Instance.Usuari.Id, "")
        Configuracio.Instance.Servei.GetTipusArticlesAsync(True, "")

    End Sub
    Private Sub btnDesconectar_Click(sender As Object, e As System.Windows.RoutedEventArgs) Handles btnDesconectar.Click
        Configuracio.Instance.Usuari = Nothing
        NavigationService.Navigate(New Uri("/Inici.xaml", UriKind.RelativeOrAbsolute))
    End Sub
    Private Sub btnModificar_Click(sender As Object, e As System.Windows.RoutedEventArgs) Handles btnModificar.Click
        NavigationService.Navigate(New Uri("/MantenimentUsuari.xaml", UriKind.RelativeOrAbsolute))
    End Sub

#Region "Mostrar Dades"

    Private Sub ClientReservesCompleted(ByVal sender As Object, ByVal e As ServeiChiquiPark.GetClientReservesCompletedEventArgs)
        lvReserves.ItemsSource = e.Result
    End Sub
    Private Sub TipusArticlesCompleted(ByVal sender As Object, ByVal e As ServeiChiquiPark.GetTipusArticlesCompletedEventArgs)
        cmbActivitats.ItemsSource = e.Result
        If cmbActivitats.Items.Count > 0 Then cmbActivitats.SelectedIndex = 0
    End Sub
    Private Sub lvReserves_MouseLeftButtonUp(sender As Object, e As System.Windows.Input.MouseButtonEventArgs) Handles lvReserves.MouseLeftButtonUp

        Dim col As Collections.Generic.IEnumerable(Of UIElement) = VisualTreeHelper.FindElementsInHostCoordinates(e.GetPosition(Nothing), sender)

        Dim row As Object = col.FirstOrDefault()
        If TypeOf row Is TextBlock OrElse TypeOf row Is Grid Then
            Dim res As New ServeiChiquiPark.Reserva
            If TypeOf row Is TextBlock Then res = CType(row, TextBlock).DataContext
            If TypeOf row Is Grid Then res = CType(row, Grid).DataContext
            If res.Id = IdSeleccionat Then
                ResetTextBoxes()
            Else
                For Each art As ServeiChiquiPark.Article In cmbActivitats.ItemsSource
                    If art.Id = res.Article.Id Then
                        cmbActivitats.SelectedItem = art
                    End If
                Next
                txtData.Text = res.DataText
                txtNens.Text = res.Nens.ToString
                MostrarHores(res.DataReserva)
                IdSeleccionat = res.Id
            End If
        End If

    End Sub
    Private Sub MostrarHores(data As Date)

        'If fechaModificada Then
        Configuracio.Instance.Servei.GetDiaReservesAsync(data, Configuracio.Instance.Usuari.Id)
        fechaModificada = False
        'End If

    End Sub
    Private Sub ResetTextBoxes()

        cmbActivitats.SelectedIndex = 0
        txtData.Text = ""
        cmbHores.ItemsSource = Nothing
        txtNens.Text = ""
        IdSeleccionat = -1
        lvReserves.SelectedIndex = -1

    End Sub
    Private Sub DiaReservesCompleted(ByVal sender As Object, ByVal e As ServeiChiquiPark.GetDiaReservesCompletedEventArgs)

        cmbHores.ItemsSource = e.Result

        If cmbHores.ItemsSource IsNot Nothing Then
            If lvReserves.SelectedItem IsNot Nothing Then
                For Each res As ServeiChiquiPark.Reserva In cmbHores.ItemsSource
                    If CType(lvReserves.SelectedItem, ServeiChiquiPark.Reserva).DataReserva.Hour = res.DataReserva.Hour Then
                        cmbHores.SelectedItem = res
                        Exit For
                    End If
                Next
            Else : cmbHores.SelectedIndex = 0
            End If
        End If

    End Sub

#End Region

#Region "Calendari"

    Private Sub btnCalendari_Click(sender As Object, e As System.Windows.RoutedEventArgs) Handles btnCalendari.Click

        calendari.Visibility = Windows.Visibility.Visible

    End Sub
    Private Sub calendari_SelectedDatesChanged(sender As Object, e As System.Windows.Controls.SelectionChangedEventArgs) Handles calendari.SelectedDatesChanged

        If calendari.SelectedDate IsNot Nothing Then
            Dim dt As Date = calendari.SelectedDate
            txtData.Text = dt.ToString("dd/MM/yyyy")
            calendari.Visibility = Windows.Visibility.Collapsed
            MostrarHores(dt)
        End If

    End Sub

#End Region

#Region "Validació"

    Private Sub txtData_TextChanged(sender As Object, e As System.Windows.Controls.TextChangedEventArgs) Handles txtData.TextChanged
        fechaModificada = True
    End Sub

    Private Sub txtData_KeyDown(ByVal sender As Object, ByVal e As System.Windows.Input.KeyEventArgs) Handles txtData.KeyDown

        If e.Key = Key.Enter Then
            Select Case sender.Name
                Case txtData.Name
                    txtNens.Focus()
                Case txtNens.Name
                    btnAfegir.Focus()
                Case Else
            End Select

        End If

    End Sub
    Private Sub txtData_LostFocus(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles txtData.LostFocus, txtNens.LostFocus

        If sender.Text <> "" Then
            Select Case sender.Name
                Case txtData.Name
                    Dim dt As Date
                    If Not Date.TryParse(txtData.Text, dt) Then dt = Date.MinValue
                    If dt <> Date.MinValue Then
                        txtData.Text = dt.ToString("dd/MM/yyyy")
                        MostrarHores(dt)
                    Else
                        txtData.Text = ""
                    End If
                Case txtNens.Name
                    Dim bt As Byte
                    If Not Byte.TryParse(txtNens.Text, bt) Then bt = 0
                    If bt <> 0 AndAlso bt > 0 Then
                        txtNens.Text = bt.ToString
                    Else
                        txtNens.Text = ""
                    End If
                Case Else
            End Select
        End If

    End Sub

#End Region

#Region "Manteniment Dades"

    Private Sub SetReservaCompleted(ByVal sender As Object, ByVal e As ServeiChiquiPark.SetReservaCompletedEventArgs)

        Configuracio.Instance.Servei.GetClientReservesAsync(Configuracio.Instance.Usuari.Id, "")
        ResetTextBoxes()

    End Sub
    Private Sub DeleteReservaCompleted(ByVal sender As Object, ByVal e As ServeiChiquiPark.DeleteReservaCompletedEventArgs)

        Configuracio.Instance.Servei.GetClientReservesAsync(Configuracio.Instance.Usuari.Id, "")
        ResetTextBoxes()

    End Sub
    Private Sub btnAfegir_Click(sender As Object, e As System.Windows.RoutedEventArgs) Handles btnAfegir.Click

        Dim res As New ServeiChiquiPark.Reserva

        If cmbHores.SelectedItem IsNot Nothing Then
            res.DataReserva = CType(cmbHores.SelectedItem, ServeiChiquiPark.Reserva).DataReserva
        Else : res.DataReserva = Date.MinValue
        End If
        Dim bt As Byte
        If Not Byte.TryParse(txtNens.Text, bt) Then bt = 0
        res.Nens = bt
        res.Client = Configuracio.Instance.Usuari
        res.Article = cmbActivitats.SelectedItem

        If lvReserves.SelectedIndex > -1 Then
            res.Id = CType(lvReserves.SelectedItem, ServeiChiquiPark.Reserva).Id
        Else
            res.Id = -1
        End If

        If res.DataReserva <> Date.MinValue AndAlso bt > 0 Then Configuracio.Instance.Servei.SetReservaAsync(res)
    End Sub
    Private Sub btnEliminar_Click(sender As Object, e As System.Windows.RoutedEventArgs) Handles btnEliminar.Click
        If lvReserves.SelectedIndex > -1 Then Configuracio.Instance.Servei.DeleteReservaAsync(CType(lvReserves.SelectedItem, ServeiChiquiPark.Reserva).Id)
    End Sub

#End Region
  

   
End Class

